# frozen_string_literal: true

require "spec_helper"

# rubocop:disable RSpec/FilePath
RSpec.describe Gitlab::Git::Blame, :seed_helper do
  include Gitlab::EncodingHelper
  include RepoHelpers
  include Gitlab::Popen

  before do
    stub_const('HGITALY_TEST_REPO_PATH', 'hgitaly-repo.git')
  end

  let(:user) { build(:user) }
  let(:repository) do
    repo = Gitlab::Mercurial::HgitalyRepository.new('default',
                                                    HGITALY_TEST_REPO_PATH, '', 'group/project')
    repo.unit_tests_skip_hooks = true
    status = repo.create_repository(namespace_fs_path: "group", in_subgroup: false)
    expect(status).to be(true)

    repo.multi_action(user,
                      branch_name: 'branch/default',
                      message: "Commit 0",
                      author_email: "jdoe1@heptapod.test",
                      author_name: "John Doe1",
                      actions: [{ action: :create,
                                  file_path: 'foo',
                                  content: "foo0\n" }])
    repo
  end

  describe 'lfs pointers' do
    after do
      repository.remove
    end

    it 'returns empty arrays instead of breaking' do
      # we don't know as of this writing how Mercurial LFS will be integrated
      # in Heptapod, maybe we'll go through some other methods, maybe not.
      # Meanwhile there must be no break.
      client = repository.gitaly_blob_client
      sha = repository.find_branch('branch/default').target
      ['branch/default', sha].each do |rev|
        expect(client.get_new_lfs_pointers(rev, nil, nil, nil)).to be_empty
      end
      expect(client.get_all_lfs_pointers).to be_empty
    end
  end
end
